lobby-package: lobby: Interact with the 'US Senate Lobbying Disclosure API'

lobby-packageR Documentation

lobby: Interact with the 'US Senate Lobbying Disclosure API'

Description

logo

Download and read data on lobbying in the United States Congress. Data is queried from the Senate's Application Programming Interface (https://lda.senate.gov/api/). This supports filings since 2008. Functions exist for all primary data endpoints, including queries by filings, contributions, registrations, clients, and lobbyists.

Author(s)

Maintainer: Christopher T. Kenny ctkenny@proton.me (ORCID)

See Also

Useful links:


lobby documentation built on March 3, 2026, 5:06 p.m.