| lobby-package | R Documentation |
Download and read data on lobbying in the United States Congress. Data is queried from the Senate's Application Programming Interface (https://lda.senate.gov/api/). This supports filings since 2008. Functions exist for all primary data endpoints, including queries by filings, contributions, registrations, clients, and lobbyists.
Maintainer: Christopher T. Kenny ctkenny@proton.me (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.